/*********************************************************************/
/* Copyright 2009, 2010 The University of Texas at Austin.           */
/* All rights reserved.                                              */
/*                                                                   */
/* Redistribution and use in source and binary forms, with or        */
/* without modification, are permitted provided that the following   */
/* conditions are met:                                               */
/*                                                                   */
/*   1. Redistributions of source code must retain the above         */
/*      copyright notice, this list of conditions and the following  */
/*      disclaimer.                                                  */
/*                                                                   */
/*   2. Redistributions in binary form must reproduce the above      */
/*      copyright notice, this list of conditions and the following  */
/*      disclaimer in the documentation and/or other materials       */
/*      provided with the distribution.                              */
/*                                                                   */
/*    THIS  SOFTWARE IS PROVIDED  BY THE  UNIVERSITY OF  TEXAS AT    */
/*    AUSTIN  ``AS IS''  AND ANY  EXPRESS OR  IMPLIED WARRANTIES,    */
/*    INCLUDING, BUT  NOT LIMITED  TO, THE IMPLIED  WARRANTIES OF    */
/*    MERCHANTABILITY  AND FITNESS FOR  A PARTICULAR  PURPOSE ARE    */
/*    DISCLAIMED.  IN  NO EVENT SHALL THE UNIVERSITY  OF TEXAS AT    */
/*    AUSTIN OR CONTRIBUTORS BE  LIABLE FOR ANY DIRECT, INDIRECT,    */
/*    INCIDENTAL,  SPECIAL, EXEMPLARY,  OR  CONSEQUENTIAL DAMAGES    */
/*    (INCLUDING, BUT  NOT LIMITED TO,  PROCUREMENT OF SUBSTITUTE    */
/*    GOODS  OR  SERVICES; LOSS  OF  USE,  DATA,  OR PROFITS;  OR    */
/*    BUSINESS INTERRUPTION) HOWEVER CAUSED  AND ON ANY THEORY OF    */
/*    LIABILITY, WHETHER  IN CONTRACT, STRICT  LIABILITY, OR TORT    */
/*    (INCLUDING NEGLIGENCE OR OTHERWISE)  ARISING IN ANY WAY OUT    */
/*    OF  THE  USE OF  THIS  SOFTWARE,  EVEN  IF ADVISED  OF  THE    */
/*    POSSIBILITY OF SUCH DAMAGE.                                    */
/*                                                                   */
/* The views and conclusions contained in the software and           */
/* documentation are those of the authors and should not be          */
/* interpreted as representing official policies, either expressed   */
/* or implied, of The University of Texas at Austin.                 */
/*********************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <stdarg.h>
#include "common.h"

#if defined(OS_WINDOWS) && (defined(__MINGW32__) || defined(__MINGW64__))
#include <conio.h>
#undef  printf
#define printf	_cprintf
#ifdef  _vcprintf
#undef  vprintf
#define vprintf	_vcprintf
#endif
#endif

#ifndef CBLAS

#ifdef __ELF__
void __xerbla(char *, blasint *);
void BLASFUNC(xerbla)(char *, blasint *) __attribute__ ((weak, alias ("__xerbla")));
void __xerbla(char *message, blasint *info){
#else
void BLASFUNC(xerbla)(char *message, blasint *info){
#endif
 
  printf(" ** On entry to %6s parameter number %2d had an illegal value\n",
	  message, *info);

  return;
}

#else

#ifdef __ELF__
void __cblas_xerbla(blasint, char*, char*, ...);
void cblas_xerbla(blasint, char*, char*, ...) __attribute__ ((weak, alias ("__cblas_xerbla")));
void __cblas_xerbla(blasint info, char *rout, char *form, ...){
#else
void cblas_xerbla(blasint info, char *rout, char* form, ...){
#endif
   va_list argptr;
   va_start(argptr, form);
   if(info)
#if defined(OS_WINDOWS)
     printf("Parameter %d to routine %s was incorrect\n", info, rout);
#else
     fprintf(stderr, "Parameter %d to routine %s was incorrect\n", info, rout);
#endif
   vprintf(form, argptr);
   va_end(argptr);
   exit(-1);
}
#endif
